========
Glossary
========


.. if you add new entries, keep the alphabetical sorting!

.. glossary::
   :sorted:

   CLI

       Command line interface, a text interface program executed from a terminal
       (*bash*, *cmd.exe*, *PowerShell*, *zsh* etc.)

   tty

       A mode when local terminal is connected to remote shell executed in a job. Any
       key pressed by user is sent to remote shell, any print to a screen from remote
       shell is displayed on local terminal.
